@@ -189,7 +189,7 @@ class Estimator:
         if len(self.bad_frames) != 0:
             self.bad_frames = np.hstack(self.bad_frames)
         self.model = self.model / self.weights
-        self.model -= np.median(self.model)
+        self.model -= np.nanmedian(self.model)
         log.debug("Built")
 
     @staticmethod
